@@ -6,10 +6,10 @@ use std::path::PathBuf;
 use anyhow::bail;
 use anyhow::Result;
 
-use crate::environment::Environment;
 use crate::fs_util;
 use crate::shell_types::EnvChange;
 use crate::shell_types::ExecuteResult;
+use crate::shell_types::ShellPipeWriter;
 
 use super::args::parse_arg_kinds;
 use super::args::ArgKind;
@@ -17,14 +17,14 @@ use super::args::ArgKind;
 pub fn cd_command(
   cwd: &Path,
   args: Vec<String>,
-  environment: impl Environment,
+  mut stderr: ShellPipeWriter,
 ) -> ExecuteResult {
   match execute_cd(cwd, args) {
     Ok(new_dir) => {
       ExecuteResult::Continue(0, vec![EnvChange::Cd(new_dir)], Vec::new())
     }
     Err(err) => {
-      environment.eprintln(&format!("cd: {}", err));
+      stderr.write_line(&format!("cd: {}", err)).unwrap();
       ExecuteResult::Continue(1, Vec::new(), Vec::new())
     }
   }
